.. swift-scality-backend documentation master file, created by
   sphinx-quickstart on Mon Mar  2 11:48:50 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to swift-scality-backend's documentation!
=================================================

This package implements a back-end for OpenStack_ Swift_ storing objects in a
Scality_ RING installation.

.. _OpenStack: http://openstack.org
.. _Swift: http://docs.openstack.org/developer/swift/
.. _Scality: http://scality.com

Contents:

.. toctree::
   :maxdepth: 2

   installation
   supported_distros
   misc
   api/modules


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

